@@ -1,6 +1,6 @@
 package EWS::Client::Role::SOAP;
 BEGIN {
-  $EWS::Client::Role::SOAP::VERSION = '1.103531';
+  $EWS::Client::Role::SOAP::VERSION = '1.103610';
 }
 use Moose::Role;
 
@@ -53,3 +53,28 @@ sub _build_schema_path {
 no Moose::Role;
 1;
 
+
+__END__
+=pod
+
+=head1 NAME
+
+EWS::Client::Role::SOAP
+
+=head1 VERSION
+
+version 1.103610
+
+=head1 AUTHOR
+
+Oliver Gorwits <oliver@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by University of Oxford.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
